Crate aead

Authenticated Encryption with Associated Data (AEAD) traits

This crate provides an abstract interface for AEAD ciphers, which guarantee both confidentiality and integrity, even from a powerful attacker who is able to execute chosen-ciphertext attacks. The resulting security property, ciphertext indistinguishability, is considered a basic requirement for modern cryptographic implementations.

See RustCrypto/AEADs for cipher implementations which use this trait.

Modules

generic_array
This crate implements a structure that can be used as a generic array type. Core Rust array types [T; N] can’t be used generically with respect to N, so for example this:
rand_core
Random number generation traits

Structs

Error
Error type.
OsRng
A random number generator that retrieves randomness from the operating system.
Payload
AEAD payloads (message + AAD).

Traits

Aead
Authenticated Encryption with Associated Data (AEAD) algorithm.
AeadCore
Authenticated Encryption with Associated Data (AEAD) algorithm core trait.
AeadInPlace
In-place stateless AEAD trait.
AeadMut
Stateful Authenticated Encryption with Associated Data algorithm.
AeadMutInPlace
In-place stateful AEAD trait.
Buffer
In-place encryption/decryption byte buffers.
KeyInit
Types which can be initialized from key.
KeySizeUser
Types which use key for initialization.

Type Aliases

Key
Key used by KeySizeUser implementors.
Nonce
Nonce: single-use value for ensuring ciphertexts are unique
Result
Result type alias with Error.
Tag
Tag: authentication code which ensures ciphertexts are authentic