Authenticated Encryption with Associated Data (AEAD) traits
This crate provides an abstract interface for AEAD ciphers, which guarantee both confidentiality and integrity, even from a powerful attacker who is able to execute chosen-ciphertext attacks. The resulting security property, ciphertext indistinguishability, is considered a basic requirement for modern cryptographic implementations.
See RustCrypto/AEADs for cipher implementations which use this trait.
Modules
- generic_
array - This crate implements a structure that can be used as a generic array type.
Core Rust array types
[T; N]can’t be used generically with respect toN, so for example this: - rand_
core - Random number generation traits
Structs
- Error
- Error type.
- OsRng
- A random number generator that retrieves randomness from the operating system.
- Payload
- AEAD payloads (message + AAD).
Traits
- Aead
- Authenticated Encryption with Associated Data (AEAD) algorithm.
- Aead
Core - Authenticated Encryption with Associated Data (AEAD) algorithm core trait.
- Aead
InPlace - In-place stateless AEAD trait.
- AeadMut
- Stateful Authenticated Encryption with Associated Data algorithm.
- Aead
MutIn Place - In-place stateful AEAD trait.
- Buffer
- In-place encryption/decryption byte buffers.
- KeyInit
- Types which can be initialized from key.
- KeySize
User - Types which use key for initialization.